@@ -10,14 +10,7 @@ aracne.net <- function( mim, eps=0 )
       else stop("Supply a matrix-like argument")      
       if(ncol(mim) != nrow(mim))
           stop("Argument matrix must be square")
-
-      res <- .C( "aracne",
-            as.double(mim),
-            as.integer(ncol(mim)),
-            as.double(eps),
-            res = double(ncol(mim)*ncol(mim)),
-            DUP=FALSE,PACKAGE="minet")$res
-
+      res <- .Call("aracne",mim,nrow(mim),eps,DUP=FALSE,PACKAGE="minet")
       dim(res) <- dim(mim)
       res <- as.data.frame(res)
       names(res)<-var.id
