@@ -8,15 +8,9 @@ clr.net <- function( mim )
       else if( is.matrix(mim) ) 
             var.id <- names(as.data.frame(mim))
       else stop("Supply a matrix-like argument")      
-      if(ncol(mim) != nrow(mim))
+      if(ncol(mim)!=nrow(mim))
           stop("Argument matrix must be square")
- 
-      res <- .C( "clrnet",
-            as.double(mim),
-            as.integer(ncol(mim)),
-            res = double(ncol(mim)*ncol(mim)),
-            DUP=FALSE,PACKAGE="minet")$res
-
+      res <- .Call( "clr", mim, nrow(mim), DUP=FALSE,PACKAGE="minet" )
       dim(res) <- dim(mim)
       res <- as.data.frame(res)
       names(res)<-var.id
